@@ -28,11 +28,10 @@
 
 #include <glib/gmacros.h>
 #include <gtk/gtkiconfactory.h>
+#include <gtk/gtkstock.h>
 
 G_BEGIN_DECLS
 
-extern void init_gnome_stock_icons (void);
-
 #define GNOME_STOCK_TIMER "gnome-stock-timer"
 #define GNOME_STOCK_TIMER_STOP "gnome-stock-timer-stop"
 #define GNOME_STOCK_TRASH "gnome-stock-trash"
@@ -92,7 +91,7 @@ extern void init_gnome_stock_icons (void);
 #define GNOME_STOCK_PIXMAP_PROPERTIES  GTK_STOCK_PROPERTIES
 #define GNOME_STOCK_PIXMAP_PREFERENCES GTK_STOCK_PREFERENCES
 #define GNOME_STOCK_PIXMAP_HELP        GTK_STOCK_HELP
-#define GNOME_STOCK_PIXMAP_SCORES      GNOME_STOCK_PIXMAP_SCORES
+#define GNOME_STOCK_PIXMAP_SCORES      GNOME_STOCK_SCORES
 #define GNOME_STOCK_PIXMAP_PRINT       GTK_STOCK_PRINT
 #define GNOME_STOCK_PIXMAP_SEARCH      GTK_STOCK_FIND
 #define GNOME_STOCK_PIXMAP_SRCHRPL     GTK_STOCK_FIND_AND_REPLACE
